{% include "channels/include/menu.html" %}
----------------
<ul>
{% for album in context %}
  <li><a href="{% url 'articles:album_open' album.channel.long_slug album.slug %}" alt="{{ album.short_title }}">{{ album.title }}</a></li>
{% endfor %}
</ul>

{% include 'articles/include/paginate.html' %}
