{% extends "containers/base.html" %}

{% block content %}

{% include "channels/include/menu.html" %}

<div class="row-fluid">
  <div class="span12">
    <div class="page-header">
      <h1>{{ context.title }}</h1>
      <small>{{ context.short_title }}</small>

      {{ context.content|safe }}

      {% comment %}
      <p>
      {% for tag in context.get_tags %}
      <a class="btn" href="{% url 'containers:tag_open' tag.slug %}">{{ tag.name }} »</a>
      {% endfor %}
      </p>
      {% endcomment %}

    </div>
  </div>
</div>
{% endblock %}
