.table-files {
    width: 100%;
}

.table-files .size {
    width: 60px;
    text-align: center;
    vertical-align: middle;
}

.table-files .preview {
    width: 50px;
    vertical-align: middle;
}

.table-files .extra {
    width: 20%;
}

.table-files .extra label {
    display: block;
    width: 100%;
    margin-bottom: 5px;
}

.table-files .start,
.table-files .cancel {
    vertical-align: middle;
}

.table-files td {
    vertical-align: middle;
}

.table-files .start button,
.table-files .cancel button {
    width: 100%;
    margin: 0;
    display: block;
    padding: 4px 15px;
    font-weight: bold;
    -webkit-border-radius: 30px;
    -moz-border-radius: 30px;
    -ms-border-radius: 30px;
    -o-border-radius: 30px;
    border-radius: 30px;
    color: #fff;
    border: 1px solid #777;
    opacity: .5;
    background: url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgi…pZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIGZpbGw9InVybCgjZ3JhZCkiIC8+PC9zdmc+IA==');
    background: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #999999), color-stop(100%, #888888));
    background: -webkit-linear-gradient(#999999,#888888);
    background: -moz-linear-gradient(#999999,#888888);
    background: -o-linear-gradient(#999999,#888888);
    background: linear-gradient(#999999,#888888);
}

.table-files .success-message {
    vertical-align: middle;
    font-weight: 700;
    text-align: center;
    color: green;
}