{% load mptt_tags %}
<div class="row-fluid">
  <div class="span12">
    <div class="navbar">
      <div class="navbar-inner">
        <div class="container-fluid">
          <a data-target=".navbar-responsive-collapse" data-toggle="collapse" class="btn btn-navbar">
            <span class="icon-bar"></span><span class="icon-bar"></span><span class="icon-bar"></span>
          </a>
          <a href="/" class="brand">Opps CMS</a>
          <div class="nav-collapse collapse navbar-responsive-collapse">
            <ul class='nav'>
              {% recursetree opps_menu %}
              <li><a href="{% url 'containers:channel' node.long_slug %}">{{ node.name }}</a>
                {% if not node.is_leaf_node %}
                <ul class="children">{{ children }}</ul>
                {% endif %}
              </li>
              {% endrecursetree %}
            </ul>
          </div>
        </div>
      </div>
    </div>
  </div>
</div>
