{% load container_tags images_tags %}

{% if obj.main_image %}
<a href="{{obj.get_absolute_url}}">
    <img src="{{ obj.main_image.image_url }}" width="500" alt="{{obj.title}}">
</a>
{% endif %}

{% if obj.child_class = 'Post' %}
 {% autoescape off %}
    {% get_post_content obj.post %}
 {% endautoescape %}
{% elif obj.child_class = 'Album' %}
    {{obj.headline|safe}}
{% elif obj.child_class = 'Link' %}
    {{obj.headline|safe}}
{% else %}
    {{obj.headline|safe}}
{% endif %}
