{% extends "admin/change_list.html" %}
{% load admin_list i18n mptt_admin %}

{% block result_list %}
  {% mptt_result_list cl %}
  {% if action_form and actions_on_bottom and cl.full_result_count %}{% admin_actions %}{% endif %}
{% endblock %}
