<html lang="en">
<head>
    <meta charset="utf-8">
    <title>Django Jquery file upload demo</title>
    <meta name="description" content="">
    <meta name="viewport" content="width=device-width">
    <!-- Bootstrap CSS Toolkit styles -->
    <link rel="stylesheet" href="{{ STATIC_URL }}css/bootstrap.min.css">
    <!-- Generic page styles -->
    <link rel="stylesheet" href="{{ STATIC_URL }}css/style.css">
    <!-- Bootstrap styles for responsive website layout, supporting different screen sizes -->
    <link rel="stylesheet" href="{{ STATIC_URL }}css/bootstrap-responsive.min.css">
    <!-- CSS to style the file input field as button and adjust the Bootstrap progress bars -->
    <link rel="stylesheet" href="{{ STATIC_URL }}css/bootstrap-image-gallery.min.css">
    <link rel="stylesheet" href="{{ STATIC_URL }}css/jquery.fileupload-ui.css">
    <!-- Shim to make HTML5 elements usable in older Internet Explorer versions -->
    <!--[if lt IE 9]><script src="http://html5shim.googlecode.com/svn/trunk/html5.js"></script><![endif]-->
</head>
<body>
    <div class="navbar navbar-fixed-top">
        <div class="navbar-inner">
            <div class="container">
                <a class="btn btn-navbar" data-toggle="collapse" data-target=".nav-collapse">
                    <span class="icon-bar"></span>
                    <span class="icon-bar"></span>
                    <span class="icon-bar"></span>
                </a>
                <a class="brand" href="https://github.com/sigurdga/django-jquery-file-upload">Django Jquery file upload</a>
                <div class="nav-collapse">
                    <ul class="nav">
                        <li class="active"><a href="#">Demo</a></li>
                        <li><a href="https://github.com/sigurdga/django-jquery-file-upload">Source Code</a></li>
                        <li><a href="https://github.com/blueimp/jQuery-File-Upload/wiki">Documentation</a></li>
                    </ul>
                </div>
            </div>
        </div>
    </div>
    {% block content %}

    <h1>No content set</h1>

    {% endblock %}
</body>
</html>


{% extends "fileupload_base.html" %}