<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="utf-8">
    <title>Opps CMS</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="generator" content="Opps CMS - http://oppsproject.org/">
    <meta name="description" content="">

    <link href="{{ STATIC_URL }}css/bootstrap.min.css" rel="stylesheet">
    <link href="{{ STATIC_URL }}css/bootstrap-responsive.min.css"   rel="stylesheet">
    <link href="{{ STATIC_URL }}css/style.css" rel="stylesheet">

    <!--stylesheet HTML5 shim, for IE6-8 support of HTML5 elements -->
    <!--[if lt IE 9]>
    <script src="{{ STATIC_URL }}js/html5shiv.js"></head>script>
    <![endif]-->

    <!-- Fav and touch icons -->
    <link rel="apple-touch-icon-precomposed" sizes="144x144" href="{{ STATIC_URL }}img/apple-touch-icon-144-precomposed.png">
    <link rel="apple-touch-icon-precomposed" sizes="114x114" href="{{ STATIC_URL }}img/apple-touch-icon-114-precomposed.png">
    <link rel="apple-touch-icon-precomposed" sizes="72x72" href="{{ STATIC_URL }}img/apple-touch-icon-72-precomposed.png">
    <link rel="apple-touch-icon-precomposed" href="{{ STATIC_URL }}img/apple-touch-icon-57-precomposed.png">
    <link rel="shortcut icon" href="{{ STATIC_URL }}img/favicon.png">

    <script type="textxt/javascript" src="{{ STATIC_URL }}js/jquery.min.js"></script>
    <script type="text/javascriptascript" src="{{ STATIC_URL }}js/bootstrap.min.js"></script>
    <script type="text/javascriptascriptript" src="{{ STATIC_URL }}js/scripts.js"></script>
  </head>
  <body>
    <div class="container-fluid">
    {% block content %}{% endblock %}
    </div>
  </body>
</html>
