{% extends "containers/base.html" %}
{% load i18n %}

{% block content %}

{% include "channels/include/menu.html" %}

<div class="row-fluid">
  <div class="alert alert-block">
    <h4>{% trans "Warning" %}!</h4>
    <p>{% trans "You don't have any channels set as home page. Please set one" %}</p>
  </div>
</div>
{% endblock %}
